#!/usr/bin/python
# -*- coding: utf-8 -*-

class TagAPI(object):

    def list_tags(self, *args, **kwargs):
        url = self.base_url + "tags"
        contents = self.get(url, **kwargs)
        return contents

    def get_tag(self, id):
        url = self.base_url + "tags/%s" % id
        contents = self.get(url)
        return contents

    def create_tag(self, id):
        return self.update_tag_state(id, "created")

    def activate_tag(self, id):
        return self.update_tag_state(id, "active")

    def inactivate_tag(self, id):
        return self.update_tag_state(id, "inactive")

    def disable_tag(self, id):
        return self.update_tag_state(id, "disabled")

    def expire_tag(self, id):
        return self.update_tag_state(id, "expired")

    def create_tag_by_code(self, code):
        return self.update_tag_state_by_code(code, "created")

    def activate_tag_by_code(self, code):
        return self.update_tag_state_by_code(code, "active")

    def inactivate_tag_by_code(self, code):
        return self.update_tag_state_by_code(code, "inactive")

    def disable_tag_by_code(self, code):
        return self.update_tag_state_by_code(code, "disabled")

    def expire_tag_by_code(self, code):
        return self.update_tag_state_by_code(code, "expired")

    def update_tag_state(self, id, state):
        url = self.base_url + "tags/%s/partial" % id
        data_j = dict(
            state = state
        )
        contents = self.patch(url, data_j = data_j)
        return contents

    def update_tag_state_by_code(self, code, state):
        url = self.base_url + "tags/byCode/%s/partial" % code
        data_j = dict(
            state = state
        )
        contents = self.patch(url, data_j = data_j)
        return contents



#!/usr/bin/python
# -*- coding: utf-8 -*-

import appier

from . import tag
from . import product

UN1QNX_BASE_URL = "https://un1qone-backend-test.azurewebsites.net/api/v2/"
""" The default base URL to be used when no other
base URL value is provided to the constructor """

UN1QNX_AUTH_URL = "https://un1qone-identity-server-test.azurewebsites.net/"
""" The default auth URL to be used when no other
auth URL value is provided to the constructor """

class API(
    appier.API,
    tag.TagAPI,
    product.ProductAPI
):

    def __init__(self, *args, **kwargs):
        appier.API.__init__(self, *args, **kwargs)
        self.base_url = appier.conf("UN1QNX_BASE_URL", UN1QNX_BASE_URL)
        self.auth_url = appier.conf("UN1QNX_AUTH_URL", UN1QNX_AUTH_URL)
        self.base_url = kwargs.get("base_url", self.base_url)
        self.auth_url = kwargs.get("auth_url", self.auth_url)
        self.token = kwargs.get("token", None)
        self.client_id = kwargs.get("client_id", None)
        self.client_secret = kwargs.get("client_secret", None)
        self.grant_type = kwargs.get("grant_type", "client_credentials")

    def build(
        self,
        method,
        url,
        data = None,
        data_j = None,
        data_m = None,
        headers = None,
        params = None,
        mime = None,
        kwargs = None
    ):
        auth = kwargs.pop("auth", True)
        if auth: headers["Authorization"] = self.auth_header()

    def get_token(self):
        if self.token: return self.token

        url = self.auth_url + "connect/token"
        params = dict(
            client_id = self.client_id,
            client_secret = self.client_secret,
            grant_type = self.grant_type
        )
        contents = self.post(url, params = params, auth = False)

        self.token = contents.get("access_token", None)
        return self.token

    def auth_callback(self, params, headers):
        self.token = None
        headers["Authorization"] = self.auth_header()

    def auth_header(self):
        return "Bearer %s" % self.get_token()



#!/usr/bin/python
# -*- coding: utf-8 -*-

class ProductAPI(object):

    def list_products(self, *args, **kwargs):
        url = self.base_url + "products"
        contents = self.get(url, **kwargs)
        return contents

    def get_product(self, id):
        url = self.base_url + "products/%s" % id
        contents = self.get(url)
        return contents
